.. _guide:

User guide
==========

This user guide provides installation instructions, an overview of the features,
some core concepts of the code, as well as usage examples.

.. attention::
    The ``yaw_cli`` commandline tool (installed through the
    ``yet_another_wizz_cli`` package) is deprecated starting with version 3.0.

    It may be reimplemented in a future release of `yet_another_wizz` with a
    limited feature set.


.. dropdown:: :octicon:`list-ordered;1.5em` ‎ ‎ ‎ Table of contents
    :open:
    :margin: 0
    :color: muted
    :class-title: h5

    .. toctree::
        :maxdepth: 2
        :includehidden:

        user_guide/getting_started
        user_guide/features
        user_guide/concepts
        user_guide/examples
